pub struct ChaosTranscriptReport {
pub scenario_id: String,
pub input_messages: usize,
pub output_messages: usize,
pub dropped_frames: usize,
pub duplicated_frames: usize,
pub reordered_frames: usize,
pub corrupted_frames: usize,
pub invariant_ok: bool,
pub violation_code: Option<String>,
}Expand description
Result of applying a deterministic chaos scenario to a server transcript.
Fields
scenario_id: Stringinput_messages: usizeoutput_messages: usizedropped_frames: usizeduplicated_frames: usizereordered_frames: usizecorrupted_frames: usizeinvariant_ok: boolviolation_code: Option<String>Trait Implementations
Sourceimpl Clone for ChaosTranscriptReport
impl Clone for ChaosTranscriptReport
Sourcefn clone(&self) -> ChaosTranscriptReport
fn clone(&self) -> ChaosTranscriptReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChaosTranscriptReport
impl Debug for ChaosTranscriptReport
Sourceimpl PartialEq for ChaosTranscriptReport
impl PartialEq for ChaosTranscriptReport
Sourcefn eq(&self, other: &ChaosTranscriptReport) -> bool
fn eq(&self, other: &ChaosTranscriptReport) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for ChaosTranscriptReport
impl StructuralPartialEq for ChaosTranscriptReport